##  Objectives
Define your objectives and link them to your business capabilities for a holistic view.
Define Objectives to improve the business:
  1. Allows high-level progress tracking
  2. Identifies critical business capabilities
  3. Enables organization-wide transparency
